% Example script for recursive Levenberg-Marquardt reassignment and recursive
% Synchrosqueezing
% 
% select the test signal setting the variable signal in 1-6
%
%
% Author: D. Fourer (dominique@fourer.fr)
% Date: Sept 2015
% Ref: [D.Fourer, F. Auger and P.Flandrin. Recursive versions of the Levenberg-Marquardt
% reassigned spectrogram and of the synchrosqueezed STFT. IEEE Proc. ICASSP 2016.]

clear all
close all

signal=1;
%% used for zero-padding for Reconstruction Quality computation
N_0pad = 100;
z      = zeros(N_0pad, 1);

%% 1: Load test signal
M = 300;
mi = 1;mf = round(M/2);

k_range   = [5];
L_range   = [7];
SNR_range = [45 35 25 15 5];
%n0_range0 = [8 18 27];
mu_range = [0.3 0.8 1.3 1.8 2.3 2.8];
M_range = [100 200 600 1000 2400];

alpha  = 0.4;           %% used for display
alpha2 = 0.25;          %% used for display

load_signal;
figure(6); 
subplot(211); plot(real(s));
subplot(212); plot(imag(s));

n_range0 = N_0pad+(1:N);

s_ref = s;
Mr = mf-mi+1;

chemin  = sprintf('figs/%d/', signal);
chemin1 = sprintf('%s/reass', chemin);    %% reass

if ~exist(chemin1, 'dir')
 mkdir(chemin1);
end

t = (1:length(s))-1;

%%
index2 = 1;              %% used for figures indices
for rsb_target = SNR_range 

  s = sigmerge(s_ref,randn(size(s_ref)),rsb_target);
  s = [z;s];                         %% 0 padding used for reconstruction
  rsb = SNR(s_ref, s(n_range0));
  fprintf('rsb_target= %f dB, rsb = %f dB\n', rsb_target, rsb);
  
  if abs(rsb - rsb_target) > 1
    error('Invalid SNR')
  end
    
  rsb = rsb_target;
  
 for k = k_range
  for L = L_range
  
    %% 2a) Recursive Reassigned spectrogram - index2/chemin1
    [~, rtfr, nfreqs, before, after, below, over] = recursive_rsp(s, k, L, mi, mf, M);
    figure(2)
    imagesc(t, nfreqs, rtfr(:,n_range0).^alpha);
    set(gca,'YDir','normal')
    colormap gray;
    cmap = colormap;
    cmap = flipud(cmap);
    colormap(cmap); 
    xlabel('time samples', 'FontSize', 16)  %, 'FontName', 'Times-Roman', 'FontSize', 20
    ylabel('normalized frequency', 'FontSize', 16)
    %ylabel('frequency  [Hz]', 'FontSize', 16)
    title(sprintf('Recurs. reass. spectrogram k=%d, L=%d, SNR=%d dB', k, L, rsb), 'FontSize', 14);
    saveas(gcf, sprintf('%s/rrspectrum_%d.eps', chemin1, index2), 'epsc');
    index2 = index2 + 1;

    %% 2b) Recursive Levenberg-Marquardt Reassigned spectrogram
    for i = 1:length(mu_range)
     mu = mu_range(i);
     [~, lmrtfr, nfreqs, before, after, below, over]   = recursive_lmrsp(s, k, L, mi, mf, M, mu);

     figure(3)
     imagesc(t, nfreqs,  lmrtfr(:,n_range0).^alpha);
     set(gca,'YDir','normal')
     colormap gray;
     cmap = colormap;
     cmap = flipud(cmap);
     colormap(cmap); 
     xlabel('time samples', 'FontSize', 16)  %, 'FontName', 'Times-Roman', 'FontSize', 20
     ylabel('normalized frequency', 'FontSize', 16)
     %ylabel('frequency  [Hz]', 'FontSize', 16)
     title(sprintf('Recurs. LM reass. spectrogram k=%d, L=%d, \\mu=%0.02f, SNR=%d dB', k, L, mu, rsb), 'FontSize', 14);
     saveas(gcf, sprintf('%s/rrspectrum_%d.eps', chemin1, index2), 'epsc');
     index2 = index2+1;
    end
    
  end %% L
 end %% k
end % RSB
 
eps2pdf(chemin1);