% Example script for recursive Levenberg-Marquardt reassignment and recursive
% Synchrosqueezing
% 
% select the test signal setting the variable signal in 1-6
%
%
% Author: D. Fourer (dominique@fourer.fr)
% Date: Sept 2015
% Ref: [D.Fourer, F. Auger and P.Flandrin. Recursive versions of the Levenberg-Marquardt
% reassigned spectrogram and of the synchrosqueezed STFT. IEEE Proc. ICASSP 2016.]

clear all
close all

signal=1;
%% used for zero-padding for Reconstruction Quality computation
N_0pad = 100;
z      = zeros(N_0pad, 1);

%% 1: Load test signal
M  = 300;
mi = 1;mf = round(M/2);

k_range   = [5];
L_range   = [7];
SNR_range = [45 35 25 15 5];
n0_range0 = [8 18 27];
mu_range = [0.3 0.8 1.3 1.8 2.3 2.8];

M_range = [100 200 600 1000 2400];

%alpha  = 0.4;  %% used for display
alpha2 = 0.25;  %% used for display

load_signal;
figure(6); 
subplot(211); plot(real(s));
subplot(212); plot(imag(s));

n_range0 = N_0pad+(1:N);

s_ref = s;
Mr = mf-mi+1;

chemin  = sprintf('figs/%d/', signal);
chemin2 = sprintf('%s/sync', chemin);     %% synchrosqueezing

if ~exist(chemin2, 'dir')
 mkdir(chemin2);
end

fp = fopen(sprintf('%s/results.txt', chemin2), 'wt');

t = (1:length(s))-1;

index3 = 1;                 %% used for figures indices
for rsb_target = SNR_range 
  
 s = sigmerge(s_ref,randn(size(s_ref)),rsb_target);
 s = [z;s];                         %% 0 padding used for reconstruction
 rsb = SNR(s_ref, s(n_range0));
 fprintf('rsb_target= %f dB, rsb = %f dB\n', rsb_target, rsb);
 
 if abs(rsb - rsb_target) > 1
  error('Invalid SNR')
 end
  
 rsb = rsb_target;
 
 for k = k_range
  for L = L_range
  
    fprintf(1, '\n+++ Parameters: k=%d L=%0.02f snr=%0.02f M=%d +++\n', k, L, rsb, M);
    fprintf(fp, '\n+++ Parameters: k=%d L=%0.02f snr=%0.02f M=%d +++\n', k, L, rsb, M);
  
    %% 3a) Recursive Synchrosqueezed STFT - index3 / chemin2
    n0 = round((k-1) * L);
    [tfr, stfr, nfreqs, below, over] = recursive_sstft(s, k, L, mi, mf, M, n0);
    figure(4)
    imagesc(t, nfreqs, (abs(stfr(:,n_range0)).^2).^alpha2);
    set(gca,'YDir','normal')
    colormap gray;
    cmap = colormap;
    cmap = flipud(cmap);
    colormap(cmap); 
    xlabel('time samples', 'FontSize', 16)  %, 'FontName', 'Times-Roman', 'FontSize', 20
    %ylabel('frequency  [Hz]', 'FontSize', 16)
    ylabel('normalized frequency', 'FontSize', 16)
    title(sprintf('Recurs. |Sy_k|^2 k=%d, L=%d, SNR=%d dB', k, L, rsb), 'FontSize', 14);
    saveas(gcf, sprintf('%s/rsync_sqmstft_%d.eps', chemin2, index3), 'epsc');
    index3 = index3 + 1;
    
    %% 3b) Reconstruction
    fprintf(1,'Signal reconstruction after synchrosqueezing\n');
    fprintf(fp,'Signal reconstruction after synchrosqueezing\n');
    [ s_hat] = sstft_rec(stfr, k, L, M, n0);
    n_range_rec = n_range0-n0;
    s_rec = 2*real(s_hat(n_range_rec)); %% assume the signal is real
%     figure(41)
%     plot(s_rec,'k-');
%     hold on
%     plot(s, 'g-.')
%     legend('reconstruction', 'reference')
%     title(sprintf('Signal reconstruction SNR=%0.02f', SNR(s(1:length(s_rec)), s_rec)))
    tmp_res = sprintf('Classical synchrosqueezing reconstruction n0=(k-1)L=%0.02f, M=%d - RQF=%0.02f dB\n', n0, M, SNR(s(n_range_rec), s_rec));
    fprintf(1,  tmp_res);
    fprintf(fp, tmp_res); 
    
    %% 3c) Recursive LM Synchrosqueezed STFT
    %mu_range = logspace(log10(0.2),log10(1), nbImg);
    n0 = round((k-1) * L);
    mu_curve = zeros(1, length(mu_range));
    for idx = 1:length(mu_range)
     mu = mu_range(idx);
     [tfr, lmstfr, nfreqs, below, over] = recursive_lmsstft(s, k, L, mi, mf, M, mu, n0);

     figure(5) 
     imagesc(t, nfreqs, (abs(lmstfr(:,n_range0)).^2).^alpha2);
     set(gca,'YDir','normal')
     colormap gray;
     cmap = colormap;
     cmap = flipud(cmap);
     colormap(cmap); 
     xlabel('time samples', 'FontSize', 16)  %, 'FontName', 'Times-Roman', 'FontSize', 20
     %ylabel('frequency  [Hz]', 'FontSize', 16)
     ylabel('normalized frequency', 'FontSize', 16)
     title(sprintf('Recurs. LM |Sy_k|^2 k=%d, L=%d, \\mu=%0.02f, SNR=%d dB', k, L, mu, rsb), 'FontSize', 14);
     saveas(gcf, sprintf('%s/rsync_sqmstft_%d.eps', chemin2, index3), 'epsc');
 
     %% 3d) Reconstruction
     %fprintf(1,'Signal reconstruction after synchrosqueezing\n');
     [s_hat] = sstft_rec(lmstfr, k, L, M, n0);
     n_range_rec = n_range0-n0;
     s_rec = 2*real(s_hat(n_range_rec)); %% assume the signal is real
     mu_curve(idx) = SNR(s(n_range_rec), s_rec);
     tmp_res = sprintf('LM-Synchrosqueezing reconstruction : mu=%0.02f - RQF=%0.02f dB\n', mu,  mu_curve(idx));
     fprintf(1,  tmp_res);
     fprintf(fp, tmp_res);
     index3 = index3 + 1;
    end
  end %% L
 end %% k
end % RSB
 
fclose(fp);
eps2pdf(chemin2)
